# Verification Digit PTY


[![pypi](https://img.shields.io/pypi/v/verification-digit-pty.svg)](https://pypi.org/project/verification-digit-pty/)
[![python](https://img.shields.io/pypi/pyversions/verification-digit-pty.svg)](https://pypi.org/project/verification-digit-pty/)
[![Build Status](https://github.com/luiscberrocal/verification-digit-pty/actions/workflows/dev.yml/badge.svg)](https://github.com/luiscberrocal/verification-digit-pty/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/luiscberrocal/verification-digit-pty/branch/main/graphs/badge.svg)](https://codecov.io/github/luiscberrocal/verification-digit-pty)



Library to calculate the verification digit from RUC and cedulas in Panama.


* Documentation: <https://luiscberrocal.github.io/verification-digit-pty>
* GitHub: <https://github.com/luiscberrocal/verification-digit-pty>
* PyPI: <https://pypi.org/project/verification-digit-pty/>
* Free software: MIT


## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter), [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage)
and [luiscberrocal/cookiecutter-pypackage](https://github.com/luiscberrocal/cookiecutter-pypackage) project template.
